@@ -225,8 +225,7 @@ adw_carousel_indicator_lines_snapshot (GtkWidget   *widget,
   AdwCarouselIndicatorLines *self = ADW_CAROUSEL_INDICATOR_LINES (widget);
   int i, n_points;
   double position;
-  g_autofree double *points = NULL;
-  g_autofree double *sizes = NULL;
+  double *points, *sizes;
 
   if (!self->carousel)
     return;
@@ -234,8 +233,11 @@ adw_carousel_indicator_lines_snapshot (GtkWidget   *widget,
   points = adw_swipeable_get_snap_points (ADW_SWIPEABLE (self->carousel), &n_points);
   position = adw_carousel_get_position (self->carousel);
 
-  if (n_points < 2)
+  if (n_points < 2) {
+    g_free (points);
+
     return;
+  }
 
   if (self->orientation == GTK_ORIENTATION_HORIZONTAL &&
       gtk_widget_get_direction (widget) == GTK_TEXT_DIR_RTL)
@@ -248,6 +250,9 @@ adw_carousel_indicator_lines_snapshot (GtkWidget   *widget,
     sizes[i] = points[i] - points[i - 1];
 
   snapshot_lines (widget, snapshot, self->orientation, position, sizes, n_points);
+
+  g_free (sizes);
+  g_free (points);
 }
 
 static void
@@ -377,7 +382,7 @@ adw_carousel_indicator_lines_new (void)
 
 /**
  * adw_carousel_indicator_lines_get_carousel: (attributes org.gtk.Method.get_property=carousel)
- * @self: a `AdwCarouselIndicatorLines`
+ * @self: an indicator
  *
  * Gets the displayed carousel.
  *
@@ -395,7 +400,7 @@ adw_carousel_indicator_lines_get_carousel (AdwCarouselIndicatorLines *self)
 
 /**
  * adw_carousel_indicator_lines_set_carousel: (attributes org.gtk.Method.set_property=carousel)
- * @self: a `AdwCarouselIndicatorLines`
+ * @self: an indicator
  * @carousel: (nullable): a carousel
  *
  * Sets the displayed carousel.
